
IP adresses in internal HTTP headers
-------

**Description:**

Whenever IP addresses are used in HTTP headers in internal structures of your organisation, 
an attacker could use these to enlarge his attack vector and recon your 
internal infrastructures.


**Solution:**

Never use IP addresses in internal HTTP headers.

	